offsettools.update_prolated_offset_values_of_component
======================================================

.. autofunction:: abjad.tools.offsettools.update_prolated_offset_values_of_component.update_prolated_offset_values_of_component
